==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_peace_town_recycle.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",85,34)
end

function Megane1()
    if(FLJ("ExchangeMapSystemAndTranslator")) then
        if(ITJ("MapSystem")) then
            ExchangeMapSystemForTranslator()
        else
            ExchangeTranslatorForMapSystem()
        end
    elseif(FLJ("ChatWithIgor")) then
        KEY()
        FAC("jack_normal")MS3("\n你有翻译机卖嘛？")NOD()CLR()
        FAC()CAT("二手的翻译机倒是有一个。")NOD()
        CAT("\n不过二手的也不便宜...")NOD()
        CAT("\n我当时也花了蛮多钱收来的。")NOD()CLR()
        FAC("jack_><")CAT("\n具体要多少啊...")NOD()CLR()
        FAC()CAT("\n只要1000...")NOD()CLR()
        FAC("jack_><")CAT("\n(天，我们哪来这么多钱啊..)")NOD()CLR()
        FAC("jack_normal")CAT("\n如果只是租用一天看看可以嘛？")NOD()CLR()
        FAC()CAT("也可以，")NOD()
        CAT("\n不过你们需要拿有价值的东西来交换。")NOD()CLR()
        GIT("MapSystem")
        CAT("\n比如这个- 地图系统 -")NOD()CLR()
        GIT()
        CAT("当然，")NOD()
        CAT("\n当你们不需要翻译机的时候")NOD()
        CAT("\n可以随时找我换回去。")NOD()CLR()
        FLP("ExchangeMapSystemAndTranslator")
        MSD("GetTranslator")
        ExchangeMapSystemForTranslator()
    else
        KEY()MS3("\n你们有东西要回收嘛？")NOD()CLR()
        FAC("jack_normal")CAT("\n不，我们没有..")NOD()
    end
end

function ExchangeTranslatorForMapSystem()
    KEY()
    GIT("Translator")
    FAC()CLR()MS3("\n要拿- 翻译机 - 换回 - 地图系统 -吗？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n是的，我们现在就要。")NOD()CLR()
        ITS("Translator")
        FAC()CAT("\n交出了 - 翻译机 -")NOD()CLR()
        GIT("MapSystem")
        ITP("MapSystem")
        SOU("CS_038_get_item")
        CAT("\n获得了 - 地图系统 - ")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\n不，现在先不要。")NOD()CLR()
        FAC()CAT("\n等你们用完可以随时找我换回来。")NOD()
    end
end

function ExchangeMapSystemForTranslator()
    KEY()
    GIT("MapSystem")
    FAC()CLR()MS3("\n要拿- 地图系统 - 交易 - 翻译机 -吗？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n是的，我们现在就要。")NOD()CLR()
        ITS("MapSystem")
        FAC()CAT("\n交出了 - 地图系统 -")NOD()CLR()
        GIT("Translator")
        ITP("Translator")
        SOU("CS_038_get_item")
        CAT("\n获得了 - 翻译机 - ")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\n让我们再想一下吧。")NOD()CLR()
        FAC()CAT("\n那等你们需要的时候再过来找我也行~")NOD()
    end
end

function Sprinkler1()
    KEY()
    MS4("\n这是一台洒水机。")NOD()
end

function Robot1()
    KEY()
    MS4("\n这是一个没有开机的机器人。")NOD()
end

function Motorcycle1()
    KEY()
    MS4("\n这是一片摩托车的残骸。")NOD()
end

function Motorcycle2()
    KEY()
    MS4("\n这是一辆完整摩托车。")NOD()
end

==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_peace_town_recycle.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",85,34)
end

function Megane1()
    if(FLJ("ExchangeMapSystemAndTranslator")) then
        if(ITJ("MapSystem")) then
            ExchangeMapSystemForTranslator()
        else
            ExchangeTranslatorForMapSystem()
        end
    elseif(FLJ("ChatWithIgor")) then
        KEY()
        FAC("jack_normal")MS3("\n你有翻译机卖嘛？")NOD()CLR()
        FAC()CAT("二手的翻译机倒是有一个。")NOD()
        CAT("\n不过二手的也不便宜...")NOD()
        CAT("\n我当时也花了蛮多钱收来的。")NOD()CLR()
        FAC("jack_><")CAT("\n具体要多少啊...")NOD()CLR()
        FAC()CAT("\n只要1000...")NOD()CLR()
        FAC("jack_><")CAT("\n(天，我们哪来这么多钱啊..)")NOD()CLR()
        FAC("jack_normal")CAT("\n如果只是租用一天看看可以嘛？")NOD()CLR()
        FAC()CAT("也可以，")NOD()
        CAT("\n不过你们需要拿有价值的东西来交换。")NOD()CLR()
        GIT("MapSystem")
        CAT("\n比如这个- 地图系统 -")NOD()CLR()
        GIT()
        CAT("当然，")NOD()
        CAT("\n当你们不需要翻译机的时候")NOD()
        CAT("\n可以随时找我换回去。")NOD()CLR()
        FLP("ExchangeMapSystemAndTranslator")
        MSD("GetTranslator")
        ExchangeMapSystemForTranslator()
    else
        KEY()MS3("\n你们有东西要回收嘛？")NOD()CLR()
        FAC("jack_normal")CAT("\n不，我们没有..")NOD()
    end
end

function ExchangeTranslatorForMapSystem()
    KEY()
    FAC("jack_normal")MS3("翻译机的话")
    CAT("\n说不定之后会派上大用，")NOD()
    CAT("\n就留着吧。")NOD()
    --[[
    KEY()
    GIT("Translator")
    FAC()CLR()MS3("\n要拿- 翻译机 - 换回 - 地图系统 -吗？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n是的，我们现在就要。")NOD()CLR()
        ITS("Translator")
        FAC()CAT("\n交出了 - 翻译机 -")NOD()CLR()
        GIT("MapSystem")
        ITP("MapSystem")
        SOU("CS_038_get_item")
        CAT("\n获得了 - 地图系统 - ")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\n不，现在先不要。")NOD()CLR()
        FAC()CAT("\n等你们用完可以随时找我换回来。")NOD()
    end
    --]]
end

function ExchangeMapSystemForTranslator()
    KEY()
    GIT("MapSystem")
    FAC()CLR()MS3("\n要拿- 地图系统 - 交易 - 翻译机 -吗？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n是的，我们现在就要。")NOD()CLR()
        ITS("MapSystem")
        FAC()CAT("\n交出了 - 地图系统 -")NOD()CLR()
        GIT("Translator")
        ITP("Translator")
        SOU("CS_038_get_item")
        CAT("\n获得了 - 翻译机 - ")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\n让我们再想一下吧。")NOD()CLR()
        FAC()CAT("\n那等你们需要的时候再过来找我也行~")NOD()
    end
end

function Sprinkler1()
    KEY()
    MS4("\n这是一台洒水机。")NOD()
end

function Robot1()
    KEY()
    MS4("\n这是一个没有开机的机器人。")NOD()
end

function Motorcycle1()
    KEY()
    MS4("\n这是一片摩托车的残骸。")NOD()
end

function Motorcycle2()
    KEY()
    MS4("\n这是一辆完整摩托车。")NOD()
end

function Credit_Cut()
    KEY()
    FAI(2)
    WAI(32)
    ANP("Door_GoPeaceTown",0,1)
    SNP("CS_jack_animate",11,14,1,"mainLayer","Jack1")
    WAI(16)
    ANP("Jack1","walk",1)
    WAI(16)
    SNP("CS_santa_animate",11,14,1,"mainLayer","Santa1")
    WAI(16)
    ANP("Jack1","normal",1)
    ANP("Door_GoPeaceTown",0,0)
    WAI(16)
    ANP("Santa1","walk",1)
    WAI(16)
    ANP("Santa1","normal",1)
    WAI(32)
    ANP("Jack1","back",1)
    WAI(32)
    SNP("CS_speechbubble",13,13,1,"mainLayer","Speechbubble1")
    ANP("Speechbubble1","ls_speechbubble_switchitem")
    WAI(200)
    FAO(2)
    TRA("CS_credit","Credit_Cut5",0,0)
end
